@@ -30,10 +30,20 @@
 #include <boost/lexical_cast.hpp>
 #include <boost/program_options.hpp>
 
+#include <sdf/parser.hh>
 #include <sdf/sdf.hh>
 
 #include <ignition/math/Rand.hh>
-#include "ignition/common/Profiler.hh"
+#include <ignition/math/SemanticVersion.hh>
+#include <ignition/common/Profiler.hh>
+#include <ignition/common/Filesystem.hh>
+#include <ignition/common/URI.hh>
+#ifdef _WIN32
+  // DELETE is defined in winnt.h and causes a problem with
+  // ignition::fuel_tools::REST::DELETE
+  #undef DELETE
+#endif
+#include <ignition/fuel_tools/Interface.hh>
 
 #include "gazebo/gazebo.hh"
 #include "gazebo/transport/transport.hh"
@@ -69,6 +79,26 @@ namespace gazebo
 {
   struct ServerPrivate
   {
+    void InspectSDFElement(const sdf::ElementPtr _elem)
+    {
+      if (common::getEnv("GAZEBO11_BACKWARDS_COMPAT_WARNINGS_ERRORS"))
+        return;
+
+      // SDF 1.7 and above consider invalid sibling elements of ANY type with
+      // repeated names while SDF 1.6 and lower only elements of the SAME type
+      auto sdfVersion =
+        ignition::math::SemanticVersion(_elem->OriginalVersion());
+      bool result;
+      if (sdfVersion >= ignition::math::SemanticVersion(1, 7))
+        result = sdf::recursiveSiblingUniqueNames(_elem);
+      else
+        result = sdf::recursiveSameTypeUniqueNames(_elem);
+
+      if (!result)
+        gzerr << "SDF is not valid, see errors above. "
+              << "This can lead to an unexpected behaviour." << "\n";
+    }
+
     /// \brief Boolean used to stop the server.
     static bool stop;
 
@@ -350,7 +380,13 @@ bool Server::ParseArgs(int _argc, char **_argv)
     {
       gzwarn << "Falling back on worlds/empty.world\n";
       if (!this->LoadFile("worlds/empty.world", physics))
+      {
+        gzerr << "worlds/empty.world could not be opened, "
+              << "probably because it was not found. "
+              << "Your GAZEBO_RESOURCE_PATH is probably improperly set. "
+              << "Have you sourced <prefix>/share/gazebo/setup.bash?\n";
         return false;
+      }
     }
 
     if (this->dataPtr->vm.count("profile"))
@@ -385,15 +421,6 @@ bool Server::GetInitialized() const
 bool Server::LoadFile(const std::string &_filename,
                       const std::string &_physics)
 {
-  // Quick test for a valid file
-  FILE *test = fopen(common::find_file(_filename).c_str(), "r");
-  if (!test)
-  {
-    gzerr << "Could not open file[" << _filename << "]\n";
-    return false;
-  }
-  fclose(test);
-
   // Load the world file
   sdf::SDFPtr sdf(new sdf::SDF);
   if (!sdf::init(sdf))
@@ -402,12 +429,60 @@ bool Server::LoadFile(const std::string &_filename,
     return false;
   }
 
-  if (!sdf::readFile(common::find_file(_filename), sdf))
-  {
-    gzerr << "Unable to read sdf file[" << _filename << "]\n";
-    return false;
-  }
+  std::string filename = _filename;
+  auto filenameUri = ignition::common::URI(filename);
 
+  if (filenameUri.Scheme() == "http" || filenameUri.Scheme() == "https")
+  {
+    std::string downloadedDir = common::FuelModelDatabase::Instance()->WorldPath(filename);
+    // Find the first sdf file in the world path for now, the later intention is
+    // to load an optional world config file first and if that does not exist,
+    // continue to load the first sdf file found as done below
+    for (ignition::common::DirIter file(downloadedDir);
+         file != ignition::common::DirIter(); ++file)
+    {
+      std::string current(*file);
+      if (ignition::common::isFile(current))
+      {
+        std::string fileName = ignition::common::basename(current);
+        std::string::size_type fileExtensionIndex = fileName.rfind(".");
+        std::string fileExtension = fileName.substr(fileExtensionIndex + 1);
+
+        if (fileExtension == "sdf" || fileExtension == "world")
+        {
+          filename = current.c_str();
+          if (!sdf::readFile(filename, sdf))
+          {
+            gzerr << "Unable to read SDF from URL[" << filename << "]\n";
+            return false;
+          }
+          gzmsg << "Loading world file [" << filename << "]" << std::endl;
+        }
+      }
+    }
+  }
+  else
+  {
+    auto foundFile = common::find_file(filename);
+
+    // Quick test for a valid file
+    FILE *test = fopen(foundFile.c_str(), "r");
+    if (!test)
+    {
+      gzerr << "Could not open file[" << filename << "]\n";
+      return false;
+    }
+    fclose(test);
+
+    if (!sdf::readFile(foundFile, sdf))
+    {
+      gzerr << "Unable to read sdf file[" << filename << "]\n";
+      return false;
+    }
+
+    gzmsg << "Loading world file [" << foundFile << "]" << std::endl;
+  }
+  
   return this->LoadImpl(sdf->Root(), _physics);
 }
 
@@ -443,6 +518,8 @@ bool Server::PreLoad()
 bool Server::LoadImpl(sdf::ElementPtr _elem,
                       const std::string &_physics)
 {
+  this->dataPtr->InspectSDFElement(_elem);
+
   // If a physics engine is specified,
   if (_physics.length())
   {
