@@ -19,7 +19,7 @@
 #include <tbb/blocked_range.h>
 #include <float.h>
 
-#include <boost/bind.hpp>
+#include <boost/bind/bind.hpp>
 #include <boost/function.hpp>
 #include <boost/thread/recursive_mutex.hpp>
 #include <ignition/math/Pose3.hh>
@@ -349,18 +349,28 @@ void Model::Init()
 //////////////////////////////////////////////////
 void Model::Update()
 {
+  IGN_PROFILE("Model::Update");
   if (this->IsStatic())
     return;
 
+  IGN_PROFILE_BEGIN("lockMutex");
   boost::recursive_mutex::scoped_lock lock(this->updateMutex);
+  IGN_PROFILE_END();
 
+  IGN_PROFILE_BEGIN("jointUpdate");
   for (Joint_V::iterator jiter = this->joints.begin();
        jiter != this->joints.end(); ++jiter)
+  {
     (*jiter)->Update();
+  }
+  IGN_PROFILE_END();
 
+  IGN_PROFILE_BEGIN("jointControllerUpdate");
   if (this->jointController)
     this->jointController->Update();
+  IGN_PROFILE_END();
 
+  IGN_PROFILE_BEGIN("jointAnimations");
   if (!this->jointAnimations.empty())
   {
     common::NumericKeyFrame kf(0);
@@ -396,9 +406,12 @@ void Model::Update()
     }
     this->prevAnimationTime = this->world->SimTime();
   }
+  IGN_PROFILE_END();
 
+  IGN_PROFILE_BEGIN("nestedModelUpdate");
   for (auto &model : this->models)
     model->Update();
+  IGN_PROFILE_END();
 }
 
 //////////////////////////////////////////////////
@@ -1016,24 +1029,40 @@ std::vector<std::string> Model::SensorScopedName(
 
 //////////////////////////////////////////////////
 void Model::LoadPlugins()
+{
+  this->LoadPlugins(30);
+}
+
+//////////////////////////////////////////////////
+void Model::LoadPlugins(unsigned int _timeout)
 {
   // Check to see if we need to load any model plugins
   if (this->GetPluginCount() > 0)
   {
     int iterations = 0;
+    const int maxIterations = _timeout * 10;
 
     // Wait for the sensors to be initialized before loading
     // plugins, if there are any sensors
     while (this->GetSensorCount() > 0 && !this->world->SensorsInitialized() &&
-           iterations < 50)
+           iterations < maxIterations)
     {
       common::Time::MSleep(100);
       iterations++;
     }
 
-    // Load the plugins if the sensors have been loaded, or if there
-    // are no sensors attached to the model.
-    if (iterations < 50)
+    // Print an error message if sensors still haven't been loaded.
+    if (iterations >= maxIterations)
+    {
+      gzerr << "Sensors failed to initialize when loading model["
+        << this->GetName() << "] via the factory mechanism."
+        << " Model plugins may not function properly."
+        << " Consider setting <ignition:model_plugin_loading_timeout/>"
+        << " to a value larger than " << _timeout << " in the world file."
+        << std::endl;
+    }
+
+    // Load the model plugins
     {
       // Load the plugins
       sdf::ElementPtr pluginElem = this->sdf->GetElement("plugin");
@@ -1043,16 +1072,10 @@ void Model::LoadPlugins()
         pluginElem = pluginElem->GetNextElement("plugin");
       }
     }
-    else
-    {
-      gzerr << "Sensors failed to initialize when loading model["
-        << this->GetName() << "] via the factory mechanism."
-        << " Plugins for the model will not be loaded.\n";
-    }
   }
 
   for (auto &model : this->models)
-    model->LoadPlugins();
+    model->LoadPlugins(_timeout);
 }
 
 //////////////////////////////////////////////////
@@ -1390,17 +1413,17 @@ void Model::SetState(const ModelState &_state)
 void Model::SetScale(const ignition::math::Vector3d &_scale,
       const bool _publish)
 {
-  if (this->scale == _scale)
-    return;
-
-  this->scale = _scale;
-
-  Base_V::iterator iter;
-  for (iter = this->children.begin(); iter != this->children.end(); ++iter)
+  if (this->scale != _scale)
   {
-    if (*iter && (*iter)->HasType(LINK))
+    this->scale = _scale;
+
+    Base_V::iterator iter;
+    for (iter = this->children.begin(); iter != this->children.end(); ++iter)
     {
-      boost::static_pointer_cast<Link>(*iter)->SetScale(_scale);
+      if (*iter && (*iter)->HasType(LINK))
+      {
+        boost::static_pointer_cast<Link>(*iter)->SetScale(_scale);
+      }
     }
   }
 
