@@ -74,6 +74,9 @@ namespace gazebo
       /// \brief Ogre Material that contains the distortion shader
       public: Ogre::MaterialPtr distortionMaterial;
 
+      /// \brief Ogre Texture that contains the distortion map
+      public: Ogre::TexturePtr distortionTexture;
+
       /// \brief Connection for the pre render event.
       public: event::ConnectionPtr preRenderConnection;
 
@@ -91,6 +94,14 @@ namespace gazebo
       virtual void notifyMaterialRender(Ogre::uint32 _passId,
                                         Ogre::MaterialPtr& _material)
       {
+        // If more compositors are added to the camera in addition to the
+        // distortion compositor, an Ogre bug will cause the material for the
+        // last camera initialized to be used for all cameras. This workaround
+        // doesn't correct the material used, but it applies the correct texture
+        // to this active material.
+        _material->getTechnique(0)->getPass(_passId)->getTextureUnitState(1)->
+          setTexture(distortionTexture);
+
         // @todo Explore more efficent implementations as it is run every frame
         Ogre::GpuProgramParametersSharedPtr params =
             _material->getTechnique(0)->getPass(_passId)
@@ -182,13 +193,18 @@ void Distortion::SetCamera(CameraPtr _camera)
   const double fov = _camera->ImageHeight() > _camera->ImageWidth() ?
       _camera->VFOV().Radian() : _camera->HFOV().Radian();
   const double focalLength = texSide/(2*tan(fov/2));
-  this->dataPtr->distortionTexWidth = texSide - 1;
-  this->dataPtr->distortionTexHeight = texSide - 1;
+  this->dataPtr->distortionTexWidth = texSide;
+  this->dataPtr->distortionTexHeight = texSide;
   unsigned int imageSize =
       this->dataPtr->distortionTexWidth * this->dataPtr->distortionTexHeight;
   double colStepSize = 1.0 / this->dataPtr->distortionTexWidth;
   double rowStepSize = 1.0 / this->dataPtr->distortionTexHeight;
 
+  // Half step-size vector to add to the value being placed in distortion map.
+  // Necessary for compositor to correctly interpolate pixel values.
+  const auto halfTexelSize =
+      0.5 * ignition::math::Vector2d(rowStepSize, colStepSize);
+
   // initialize distortion map
   this->dataPtr->distortionMap.resize(imageSize);
   for (unsigned int i = 0; i < this->dataPtr->distortionMap.size(); ++i)
@@ -244,9 +260,10 @@ void Distortion::SetCamera(CameraPtr _camera)
       }
 
       // compute the index in the distortion map
-      distortedCol = distortedLocation.X() * this->dataPtr->distortionTexWidth;
-      distortedRow = distortedLocation.Y() *
-        this->dataPtr->distortionTexHeight;
+      distortedCol = round(distortedLocation.X() * 
+        this->dataPtr->distortionTexWidth);
+      distortedRow = round(distortedLocation.Y() *
+        this->dataPtr->distortionTexHeight);
 
       // Note that the following makes sure that, for significant distortions,
       // there is not a problem where the distorted image seems to fold over
@@ -277,12 +294,14 @@ void Distortion::SetCamera(CameraPtr _camera)
           if (newDistortedCoordinates.Distance(distortionCenterCoordinates) <
               currDistortedCoordinates.Distance(distortionCenterCoordinates))
           {
-            this->dataPtr->distortionMap[distortedIdx] = normalizedLocation;
+            this->dataPtr->distortionMap[distortedIdx] = normalizedLocation +
+              halfTexelSize;
           }
         }
         else
         {
-          this->dataPtr->distortionMap[distortedIdx] = normalizedLocation;
+          this->dataPtr->distortionMap[distortedIdx] = normalizedLocation +
+            halfTexelSize;
         }
       }
       // else: mapping is outside of the image bounds.
@@ -301,7 +320,7 @@ void Distortion::SetCamera(CameraPtr _camera)
 
   // create the distortion map texture for the distortion instance
   std::string texName = _camera->Name() + "_distortionTex";
-  Ogre::TexturePtr renderTexture =
+  this->dataPtr->distortionTexture =
       Ogre::TextureManager::getSingleton().createManual(
           texName,
           "General",
@@ -310,7 +329,8 @@ void Distortion::SetCamera(CameraPtr _camera)
           this->dataPtr->distortionTexHeight,
           0,
           Ogre::PF_FLOAT32_RGB);
-  Ogre::HardwarePixelBufferSharedPtr pixelBuffer = renderTexture->getBuffer();
+  Ogre::HardwarePixelBufferSharedPtr pixelBuffer =
+      this->dataPtr->distortionTexture->getBuffer();
 
   // fill the distortion map, while interpolating to fill dead pixels
   pixelBuffer->lock(Ogre::HardwareBuffer::HBL_NORMAL);
@@ -433,6 +453,16 @@ void Distortion::SetCamera(CameraPtr _camera)
 //////////////////////////////////////////////////
 void Distortion::RefreshCompositor(CameraPtr _camera)
 {
+  // If no distortion is required, immediately return.
+  if (ignition::math::equal(this->dataPtr->k1, 0.0) &&
+      ignition::math::equal(this->dataPtr->k2, 0.0) &&
+      ignition::math::equal(this->dataPtr->k3, 0.0) &&
+      ignition::math::equal(this->dataPtr->p1, 0.0) &&
+      ignition::math::equal(this->dataPtr->p2, 0.0))
+  {
+    return;
+  }
+
   if (this->dataPtr->lensDistortionInstance) {
     Ogre::CompositorManager::getSingleton().removeCompositor(
       _camera->OgreViewport(), this->dataPtr->compositorName);
