@@ -228,14 +228,39 @@ void JointSpawningTest::SpawnJointRotationalWorld(
   ASSERT_TRUE(physics != nullptr);
   EXPECT_EQ(physics->GetType(), _physicsEngine);
 
+  physics::JointPtr joint;
+  for (unsigned int i = 0; i < 2; ++i)
   {
-    gzdbg << "SpawnJoint " << _jointType << " child world" << std::endl;
+    bool worldChild = (i == 0);
+    bool worldParent = (i == 1);
+    std::string child = worldChild ? "world" : "child";
+    std::string parent = worldParent ? "world" : "parent";
+    gzdbg << "SpawnJoint " << _jointType << " "
+          << child << " "
+          << parent << std::endl;
 
-    physics::JointPtr joint = SpawnJoint(_jointType, false, true);
+    if ((_physicsEngine == "dart" || _physicsEngine == "simbody")
+        && worldChild)
+    {
+      // These physics engines don't support world as a child link.
+      // simbody https://github.com/osrf/gazebo/issues/861
+      // dart https://github.com/osrf/gazebo/issues/914
+      gzerr << "Skip tests for child world link cases since "
+            << _physicsEngine
+            << " does not allow joint with world as child. "
+            << "Please see github issues #861, #914."
+            << std::endl;
+      continue;
+    }
+
+    joint = SpawnJoint(_jointType, worldChild, worldParent);
     ASSERT_TRUE(joint != nullptr);
 
     physics::LinkPtr link;
-    link = joint->GetChild();
+    if (!worldChild)
+      link = joint->GetChild();
+    else if (!worldParent)
+      link = joint->GetParent();
     ASSERT_TRUE(link != nullptr);
 
     auto initialPose = link->WorldPose();
